{% include "header.html" %}

<h1>{{ template.title }} - Collection Items: {{ response.collection.title }}</h1>

<p>
  <b>Number of matching items:</b> {{ response.numberMatched }}<br/>
  <b>Number of returned items:</b> {{ response.numberReturned }}<br/>
</p>

<table>
  <thead>
    <tr>
      <th>ID</th>
{% if response.features %}
{% for key, value in response.features.0.properties %}
      <th>{{ key }}</th>
{% endfor %}
{% endif %}
    </tr>
  </thead>
  <tbody>
{% for feature in response.features %}
    <tr>
      <td><a target="_blank" href="{{ template.api_root }}/collections/{{ response.collection.id }}/items/{{ feature.id }}?f=html{{ template.extra_params }}">{{ feature.id }}</a></td>
  {% for key, value in feature.properties %}
      <td>{{ value }}</td>
  {% endfor %}
    </tr>
{% endfor %}
  </tbody>
</table>

{% include "footer.html" %}
